==> nextcloud-app-news-18.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/uk.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Запит не вдався, немає мережевого з'єднання!",
    "Request unauthorized. Are you logged in?" : "Запит не авторизований. Ви увійшли в систему?",
    "Request forbidden. Are you an admin?" : "Запит заборонений. Ви справді адміністратор?",
    "Token expired or app not enabled! Reload the page!" : "Термін дії токена закінчився або програма не задіяна! Перезагрузіть сторінку!",
    "Unread articles" : "Непрочитані статті",
    "Purge interval" : "Очистити оновлення",
    "Maximum read count per feed" : "Максимальна кількість статей для стрічки",
    "Maximum redirects" : "Максимум перенаправлень",
    "Feed fetcher timeout" : "Час очікування для завантажувача стрічки",
    "Explore Service URL" : "URL сервісу дослідження",
    "Saved" : "Збереженно",
    "Download" : "Завантажити",
    "Close" : "Закрити",
    "No articles available" : "Немає доступних статей",
    "No unread articles available" : "Немає непрочитаних записів",
    "Open website" : "Відкрити веб-сайт",
    "Star article" : "Позначити статтю",
    "Unstar article" : "Зняти позначку статті",
    "Keep article unread" : "Залишити статтю непрочитаною",
    "Remove keep article unread" : "Позначити статтю як прочитану",
    "Username" : "Ім'я користувача",
    "by" : "по",
    "from" : "З",
    "Play audio" : "Відтворення аудіо",
    "Download audio" : "Завантажити аудіо",
    "Download video" : "Завантажити відео",
    "Keyboard shortcut" : "Сполучення клавіш",
    "Description" : "Опис",
    "right" : "праворуч",
    "Jump to next article" : "Наступна стаття",
    "left" : "ліворуч",
    "Jump to previous article" : "Попередня стаття",
    "Toggle star article" : "Позначити статтю",
    "Star article and jump to next one" : "Позначити статтю та перейти до наступної",
    "Toggle keep current article unread" : "Залишити статтю непрочитаною",
    "Open article in new tab" : "Відкрити статтю в новій вкладці",
    "Toggle expand article in compact view" : "Переключити статтю в компактний режим",
    "Refresh" : "Оновити",
    "Load next feed" : "Завантажити наступну стрічку",
    "Load previous feed" : "Завантажити попередню стрічку",
    "Load previous folder" : "Завантажити попередню теку",
    "Load next folder" : "Завантажити наступну теку",
    "Scroll to active navigation entry" : "Перехід до обраного елементу",
    "Mark current article's feed/folder read" : "Зробити поточну подачу/теку артиклю лише для читання",
    "How to set up the operating system cron" : "Як налаштувати cron операційної системи",
    "Subscribe" : "Підписатися",
    "Web address" : "Веб адреса",
    "Feed exists already!" : "Стрічка вже існує !",
    "Folder" : "Папка",
    "No folder" : "Немає теки",
    "New folder" : "Нова тека",
    "Folder name" : "Ім'я теки",
    "Go back" : "Повернутися назад",
    "Folder exists already!" : "Тека вже існує !",
    "Credentials" : "Облікові дані",
    "Password" : "Пароль",
    "New Folder" : "Нова тека",
    "Create" : "Створити",
    "Explore" : "Дослідити",
    "Deleted feed" : "Вилучена стрічка",
    "Undo delete feed" : "Скасувати вилучення стрічки",
    "Rename" : "Перейменувати",
    "Menu" : "Меню",
    "Mark read" : "Позначити як прочитане",
    "Newest first" : "Новіші попереду",
    "Oldest first" : "Старіші попереду",
    "Delete" : "Вилучити",
    "Dismiss" : "Припинити",
    "Collapse" : "Згорнути",
    "Deleted folder" : "Вилучені теки",
    "Undo delete folder" : "Скасувати вилучення теки",
    "Starred" : "Помічені зірочкою",
    "All articles" : "Всі статті",
    "Settings" : "Налаштування",
    "Disable mark read through scrolling" : "Вимкнути читання поміток при прокрутці",
    "Compact view" : "Компактний вигляд",
    "Expand articles on key navigation" : "Розширенні артикули під час навігації по ключах",
    "Show all articles" : "Показати всі статті",
    "Reverse ordering (oldest on top)" : "Зворотний порядок (найстаріші зверху)",
    "Subscriptions (OPML)" : "Підписки (OPML)",
    "Import" : "Імпорт",
    "Export" : "Експорт",
    "Unread/Starred Articles" : "Непрочитані/Вибрані статті",
    "Error when importing: file does not contain valid JSON" : "Помилка при імпорті: файл не містить дійсний JSON",
    "Help" : "Допомога",
    "Keyboard shortcuts" : "Сполучення клавіш",
    "Documentation" : "Документація",
    "Report a bug" : "Повідомити про помилку"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-news-18.2.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/uk.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Запит не вдався, немає мережевого з'єднання!",
    "Request unauthorized. Are you logged in?" : "Запит не авторизований. Ви увійшли в систему?",
    "Request forbidden. Are you an administrator?" : "Запит заборонено. Ви адміністратор?",
    "Token expired or app not enabled! Reload the page!" : "Термін дії токена закінчився або програма не задіяна! Перезагрузіть сторінку!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Внутрішня помилка сервера! Щоб отримати додаткову інформацію, перевірте файл data/nextcloud.log!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Помилка запиту, Nextcloud зараз у режимі обслуговування!",
    "Unread articles" : "Непрочитані статті",
    "Use system cron for updates" : "Використовуйте системний cron для оновлень",
    "Purge interval" : "Очистити оновлення",
    "Maximum read count per feed" : "Максимальна кількість статей для стрічки",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Визначає максимальну кількість статей, які можна прочитати на канал, які не будуть видалені під час завдання очищення; якщо старі статті знову з’являються після прочитання, збільште це значення; від'ємні значення, такі як -1, вимкнуть цю функцію.",
    "Maximum redirects" : "Максимум перенаправлень",
    "Feed fetcher timeout" : "Час очікування для завантажувача стрічки",
    "Explore Service URL" : "URL сервісу дослідження",
    "Successfully updated news configuration" : "Конфігурацію новин успішно оновлено",
    "Download" : "Завантажити",
    "Close" : "Закрити",
    "No articles available" : "Немає доступних статей",
    "No unread articles available" : "Немає непрочитаних записів",
    "Open website" : "Відкрити веб-сайт",
    "Star article" : "Позначити статтю",
    "Unstar article" : "Зняти позначку статті",
    "Keep article unread" : "Залишити статтю непрочитаною",
    "Remove keep article unread" : "Позначити статтю як прочитану",
    "Share" : "Поділитися",
    "Username" : "Ім'я користувача",
    "by" : "по",
    "from" : "З",
    "Play audio" : "Відтворення аудіо",
    "Download audio" : "Завантажити аудіо",
    "Download video" : "Завантажити відео",
    "Keyboard shortcut" : "Сполучення клавіш",
    "Description" : "Опис",
    "right" : "праворуч",
    "Jump to next article" : "Наступна стаття",
    "left" : "ліворуч",
    "Jump to previous article" : "Попередня стаття",
    "Toggle star article" : "Позначити статтю",
    "Star article and jump to next one" : "Позначити статтю та перейти до наступної",
    "Toggle keep current article unread" : "Залишити статтю непрочитаною",
    "Open article in new tab" : "Відкрити статтю в новій вкладці",
    "Toggle expand article in compact view" : "Переключити статтю в компактний режим",
    "Refresh" : "Оновити",
    "Load next feed" : "Завантажити наступну стрічку",
    "Load previous feed" : "Завантажити попередню стрічку",
    "Load previous folder" : "Завантажити попередню теку",
    "Load next folder" : "Завантажити наступну теку",
    "Scroll to active navigation entry" : "Перехід до обраного елементу",
    "Mark current article's feed/folder read" : "Зробити поточну подачу/теку артиклю лише для читання",
    "How to set up the operating system cron" : "Як налаштувати cron операційної системи",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Установіть і налаштуйте швидший паралельний засіб оновлення, який використовує API оновлення програми Новини",
    "Subscribe" : "Підписатися",
    "Web address" : "Веб адреса",
    "Feed exists already!" : "Стрічка вже існує !",
    "Folder" : "Папка",
    "No folder" : "Немає теки",
    "New folder" : "Нова тека",
    "Folder name" : "Ім'я теки",
    "Go back" : "Повернутися назад",
    "Folder exists already!" : "Тека вже існує !",
    "Credentials" : "Облікові дані",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Облікові дані HTTP Basic Auth повинні зберігатися незашифрованими! Усі, хто має доступ до сервера або бази даних, зможуть отримати до них доступ!",
    "Password" : "Пароль",
    "New Folder" : "Нова тека",
    "Create" : "Створити",
    "Explore" : "Дослідити",
    "Update failed more than 50 times" : "Помилка оновлення понад 50 разів",
    "Deleted feed" : "Вилучена стрічка",
    "Undo delete feed" : "Скасувати вилучення стрічки",
    "Rename" : "Перейменувати",
    "Menu" : "Меню",
    "Mark read" : "Позначити як прочитане",
    "Newest first" : "Новіші попереду",
    "Oldest first" : "Старіші попереду",
    "Delete" : "Вилучити",
    "Dismiss" : "Припинити",
    "Collapse" : "Згорнути",
    "Deleted folder" : "Вилучені теки",
    "Undo delete folder" : "Скасувати вилучення теки",
    "Starred" : "Помічені зірочкою",
    "All articles" : "Всі статті",
    "Settings" : "Налаштування",
    "Disable mark read through scrolling" : "Вимкнути читання поміток при прокрутці",
    "Compact view" : "Компактний вигляд",
    "Expand articles on key navigation" : "Розширенні артикули під час навігації по ключах",
    "Show all articles" : "Показати всі статті",
    "Reverse ordering (oldest on top)" : "Зворотний порядок (найстаріші зверху)",
    "Subscriptions (OPML)" : "Підписки (OPML)",
    "Import" : "Імпорт",
    "Export" : "Експорт",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Помилка під час імпорту: OPML не містить ані каналів, ані папок",
    "Unread/Starred Articles" : "Непрочитані/Вибрані статті",
    "Error when importing: file does not contain valid JSON" : "Помилка при імпорті: файл не містить дійсний JSON",
    "Help" : "Допомога",
    "Keyboard shortcuts" : "Сполучення клавіш",
    "Documentation" : "Документація",
    "Report a bug" : "Повідомити про помилку"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
